@@ -2,5 +2,5 @@
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub struct HorizontalMetrics {
     pub advance_width: f32,
-    pub left_side_bearing: f32,
+    pub(crate) left_side_bearing: f32,
 }
