@@ -1,5 +1,5 @@
 /// An extension trait for [`f32`].
-pub trait F32Ext {
+pub(crate) trait F32Ext {
     /// Linearly interpolate between `self` and `other` with parameter `t`.
     fn lerp(self, other: f32, t: f32) -> f32;
 }
