@@ -1,10 +1,9 @@
 use crate::font::{Glyph, HorizontalMetrics, Outline, OutlinePoint, VectorFont};
 use crate::geometry::{AffineTransformation, LinearTransformation, Point, Rectangle, Transform, Vector};
-use crate::internal_iter::ExtendFromInternalIterator;
 use std::{mem, result};
 
 #[derive(Clone, Debug)]
-pub struct GlyphsParser<'a> {
+pub(crate) struct GlyphsParser<'a> {
     glyphs: Vec<Option<Glyph>>,
     advance_width_count: usize,
     hmtx_table_bytes: &'a [u8],
@@ -53,7 +52,7 @@ impl<'a> GlyphsParser<'a> {
         let bytes = &self.glyf_table_bytes[start..end];
         let horizontal_metrics = self.parse_horizontal_metrics(index)?;
         Ok(if bytes.is_empty() {
-            Glyph { horizontal_metrics, bounds: Rectangle::default(), outline: Outline::new() }
+            Glyph { horizontal_metrics, bounds: Rectangle::default(), outline: Outline::default() }
         } else {
             let mut reader = Reader::new(bytes);
             let contour_count = reader.read_i16()?;
@@ -150,7 +149,7 @@ impl<'a> GlyphsParser<'a> {
             &bytes[x_coordinates_bytes_start..y_coordinates_bytes_start],
             &bytes[y_coordinates_bytes_start..],
         );
-        let mut outline = Outline::new();
+        let mut outline = Outline::default();
         let mut start = 0;
         for _ in 0..contour_count {
             let end = end_pts_for_contours_reader.read_u16()? as usize + 1;
@@ -170,7 +169,7 @@ impl<'a> GlyphsParser<'a> {
         mut horizontal_metrics: HorizontalMetrics,
         bounds: Rectangle,
     ) -> Result<Glyph> {
-        let mut outline = Outline::new();
+        let mut outline = Outline::default();
         let mut reader = Reader::new(bytes);
         let mut flags = CompositeGlyphFlags(reader.read_u16()?);
         loop {
@@ -203,9 +202,11 @@ impl<'a> GlyphsParser<'a> {
             };
             for component_contour in component_glyph.outline.contours() {
                 let mut contour = outline.begin_contour();
-                contour.extend_from_internal_iter(
-                    component_contour.points().iter().cloned().map(|point| point.transform(&AffineTransformation::new(xy, z))),
-                );
+                for item in
+                    component_contour.points().iter().cloned().map(|point| point.transform(&AffineTransformation::new(xy, z)))
+                {
+                    contour.push(item);
+                }
                 contour.end();
             }
             if !flags.more_components() {
@@ -598,7 +599,7 @@ mod tests {
 
     #[test]
     fn main() {
-        for entry in fs::read_dir(Path::new(env!("CARGO_MANIFEST_DIR")).join("../../resources")).unwrap() {
+        for entry in fs::read_dir(Path::new(env!("CARGO_MANIFEST_DIR")).join("../resources")).unwrap() {
             let path = entry.unwrap().path();
             if path.extension().unwrap() != "ttf" {
                 continue;
